# Introduction

Yamlbrew is a tool to help you use yml files to generate varied synthetic data more easily.

One of the most difficult problems of synthetic data generation is to generate data that is varied and realistic.

Yamlbrew tries to solve this problem by allowing you to define the structure of the prompt in a yml file. This makes it easy to vary your prompts easily.
